#
# spec file for package python-gwosc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname gwosc
%define         skip_python2 1

Name:           python-gwosc
Version:        0.7.1
Release:        1.6
Summary:        Python interface to the Gravitational-Wave Open Data Center archive
License:        MIT
URL:            https://gwosc.readthedocs.io/en/latest/
Source:         https://files.pythonhosted.org/packages/source/g/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION For tests
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 1.0.0}
BuildRequires:  %{python_module requests-mock}
# /SECTION
Requires:       python-requests >= 1.0.0
BuildArch:      noarch
%python_subpackages

%description
The gwosc package provides an interface to querying the open data
releases hosted on https://gw-openscience.org from the GEO, LIGO, and
Virgo gravitational-wave observatories.

%prep
%autosetup -p1 -n %{modname}-%{version}
sed -i 's/--color=yes//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}/%{modname}/

%check
# macro missing for <SLE-15-SP1, (is the science project still supporting that?)
%{?!pytest:%define pytest py.test}
# requests_mock too old for <= 15.1
%if 0%{?suse_version} == 1500 && 0%{?sle_version} <= 150100
%pytest -k "not remote and not test_fetch_json_local"
%else
%pytest -k "not remote"
%endif

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*-info/

%changelog
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.1:
  * Update all gw-openscience.org references to gwosc.org
  * Include custom User-Agent header in requests
- Changes from version 0.7.0:
  * Remove deprecated tag keyword from gwosc.locate.get_urls
  * Remove deprecated gwosc.catalog module
  * Implement query feature
  * Formally support Python 3.11
- Drop gwosc-pytest-warns.patch: incorporated upstream.
- Use wheel based builds instead of setuptools.
* Sun Jul  3 2022 Ben Greiner <code@bnavigator.de>
- Clean up specfile
- Add gwosc-pytest-warns.patch
  * Fixes pytest.PytestRemovedIn8Warning errors with newer pytest
  * part of https://git.ligo.org/gwosc/client/-/merge_requests/80
- Update Source for canonical PyPI hosted URL
- The setup.py just calls setuptools PEP517 style. Use up to date
  pip instead of the vendored one by the Python interpreter.
- Add missing runtime requirement on python-requests.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.1: No changelog.
- New BuildRequires: python-setuptools_scm, python-wheel.
* Sat Sep 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.5.6: No changelog.
- Add BuildRequires: python-requests-mock for tests.
- Disable 'test_fetch_json_local' for Leap 15.1 as requests-mock
  is too old there.
* Sat Aug  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.5.5: No changelog from upstream.
- Use src tarball from PyPI instead of those from github (see
  gh#gwpy/gwosc#55).
- Disable python2 until python2 tests are fixed.
- Use modname instead of full pkg name for source tarball.
- Simplify pytest command in %%check.
- Run fdupes to link up duplicate files.
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop the skip_python2 macro as python2 has been disabled for
  openSUSE:Factory project-wide.
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
